pub struct CompleteFormField {
pub name: String,
pub purpose: String,
pub hints: IntentHints,
pub value: ControlAction,
pub revealed_by: Option<IntentHints>,
}Fields
name: Stringpurpose: Stringhints: IntentHintsvalue: ControlActionrevealed_by: Option<IntentHints>Hints for a control to click before this field is resolved – set
when the field only exists once the fields filled so far are
submitted (for example an MFA code field revealed after email and
password are submitted). Resolved and clicked the same way a
SubmitAndVerify button is, then this field’s own target is waited
for before it is filled.