pub struct FollowIntent {
pub purpose: String,
pub hints: IntentHints,
pub expected_destination: WaitForCommand,
pub boundary: bool,
}Expand description
Follow a control and wait for the expected destination.
Set boundary when activation may mutate state or trigger a side effect
(same meaning as ClickCommand::boundary).
Fields
purpose: Stringhints: IntentHintsexpected_destination: WaitForCommandboundary: boolTrait Implementations
Sourceimpl Clone for FollowIntent
impl Clone for FollowIntent
Sourceimpl Debug for FollowIntent
impl Debug for FollowIntent
Sourceimpl<'de> Deserialize<'de> for FollowIntent
impl<'de> Deserialize<'de> for FollowIntent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more